#

    	belt

    		start:
    			./belt --label belt-1

    		ports:
    			10000
    			10001

    		structure:
    			[dir] belt-1
    				[dir] mongo_node
    					db:pouch
    						collection:card [{
    							"public": {
    								"hexadecimal string": ""
    							},
    							"private": {
    								"hexadecimal string": ""
    							},
    							"seed": {
    								"hexadecimal string": ""
    							}
    						}]

    		names:
    			./names

    		agenda:
    			./__agenda/agenda